<?php
/**
 * Created by PhpStorm.
 * User: zhuangxin
 * Date: 16-9-14
 * Time: 下午5:48
 */
namespace App\Article\Model;
use App\Traits\Models;
use Illuminate\Database\Eloquent\Model;
use App\Article\Model\Keywords;
use App\Kw\Model\Keywords as BaseKeyWords;
use Illuminate\Support\Facades\DB;

class Art extends Model
{
    use Models;

    const ARTICLE  =  0;
    const ACTIVE   =  1;

    static $NAME = [
        self::ARTICLE   => "攻略",
        self::ACTIVE    => "动态"
    ];

    const fields = [
        "id","title","cover","look_count","like_count",
        "create_time","is_hidden","comment_count","is_del",
        "shared_count"
    ];

    protected $table = "myp_article";
    public $timestamps = false;

    protected $fillable = [
        'content', 'title', 'cover', 'uid'
    ];

    public function __construct(array $attributes = [])
    {
        parent::__construct($attributes);
        $this->beforeValidationOnCreate();
    }

    public function beforeValidationOnCreate()
    {
        $this->look_count = 0;
        $this->like_count = 0;
        $this->collect_count = 0;
        $this->is_hidden = 0;
        $this->comment_count = 0;
        $this->shared_count = 0;
        $this->type = self::ARTICLE;
        $this->hot_point = 0;
        $this->is_del = 0;
        $this->create_time = date("Y-m-d H:i:s",time());
    }



    public function relation_keywords()
    {
        return $this->hasMany(Keywords::class,"article_id")->select(Keywords::fields);
    }

    /**
     * @param $data
     * @return Art|bool
     * 测试通过的第一个
     */
    public static function newArt($data)
    {
        $model = new self;
        DB::beginTransaction();
        try {
            $model->fill($data);
            if (isset($data['keywords']) && !empty($data['keywords'])) {
               $keywords_list = Keywords::newKeywords($data['keywords'],$data['uid']);
               $model->relation_keywords()->saveMany($keywords_list);
            }
            $model->save();
        } catch (\Exception $e) {
            DB::rollBack();
            return false;
        }
        DB::commit();
        return $model;
    }

    public function uptArt($data)
    {
        DB::beginTransaction();
        try {
            if (isset($data['keywords']) && !empty($data['keywords'])) {
                $keywords_list = Keywords::newKeywords($data['keywords'],$data['uid']);
                $this->relation_keywords()->delete();
                $this->relation_keywords()->saveMany($keywords_list);
            }
            $is_saved = $this->update($data);
        } catch (\Exception $e) {
            DB::rollBack();
            return false;
        }
        DB::commit();
        return $is_saved;
    }

}