<?php
/**
 * Created by PhpStorm.
 * User: zhuangxin
 * Date: 16-9-14
 * Time: 下午5:46
 */

namespace App\Article\v1\Controller;

use App\Article\Events\ArtAddEvent;
use App\Article\Validation\ArtValidator;
use App\Traits\Controller;
use App\Article\Events\ArtEditedEvent;
use Illuminate\Support\Facades\Event;
use Mockery\CountValidator\Exception;
use Symfony\Component\HttpFoundation\Request;
use App\Article\Model\Art as ArtModel;
use App\Http\Response\Response;
use App\Http\Response\HttpStatus;

class Article extends \Illuminate\Routing\Controller
{

    use Controller;

    protected $query_fields = [
        "uid","title","is_del","type"
    ];

    public function index()
    {
        $query = request()->query();
        $where = $this->filter($query);
        $model = $this->setBlurSearch(ArtModel::class,$where,"title");
        is_null($where) && $where = [];
        $row  = isset($query["size"])?$query["size"]:config("app.default_perpage");
        return Response::success($model->select(ArtModel::fields)->paginate($row)->toArray());
    }

    public function store(Request $request)
    {
        $validator = new ArtValidator();
        $post = $request->all();
        $res = $validator->validate($post);
        if ($res == false) {
            $messages = $validator->getMessages();
            return Response::error($messages,HttpStatus::HttpValidationFailed);
        }
        $this->csrf($post,'content');
        $model = ArtModel::newArt($post);
        if ($model !== false) {
            Event::fire(new ArtAddEvent($model));
            return Response::ok($model->id);
        } else {
            return Response::error();
        }
    }

    /**
     * 已测试
     * @param $id
     * @param Request $request
     * @return array
     */
    public function update($id,Request $request)
    {
        try {
            $model = ArtModel::findOrFail($id);
            $post = $request->all();
            isset($post['content']) && $post['content'] = $this->csrf($post,'content');
            $validate_Data = array_merge($model->toArray(),$post);
            $validator = new ArtValidator();
            $res = $validator->validate($validate_Data);
            if ($res == false) {
                $messages = $validator->getMessages();
                return Response::error($messages,HttpStatus::HttpValidationFailed);
            }
            $res = $model->uptArt($post);
            if ($res !== false) {
                Event::fire(new ArtEditedEvent($model));
                return Response::ok($model->id);
            } else {
                return Response::error();
            }
        } catch (\Exception $e){
            return Response::error("攻略未找到",HttpStatus::HttpNotFound);
        }
    }

    public function show($id)
    {
        try {
            $info = ArtModel::findOrFail($id);
            $info->getRelate(request("relation"));
            return Response::success($info->toArray());
        } catch (\Exception $e){
            return Response::error("攻略未找到",HttpStatus::HttpNotFound);
        }
    }

    public function getRelate($id,$relation)
    {
        try {
            $model = ArtModel::findOrFail($id , ["id"]);
            $model->getRelate($relation);
            return Response::success($model);
        } catch (\Exception $e){
            return Response::error("攻略未找到",HttpStatus::HttpNotFound);
        }
    }
}