<?php

namespace App\Libraries\ElasticSearch;
use Illuminate\Support\Facades\Log;

class Search {
    protected static $server = [];
    const SETS  = "sets";
    const WORKS = "works";
    const USER  = "user";
    const ART   = "article";

    const TYPES = [
        self::SETS => "sets",
        self::WORKS => "works",
        self::USER => "user",
        self::ART  => "article"
    ];

    protected $server_ip;
    protected $method;
    protected $request;
    protected $index_name;
    protected $type_name;
    protected $data_id;
    protected $data;

    protected function __construct($index_name)
    {
        $this->server_ip = "http://".config("app.elastic_searcher.ip").":".config("app.elastic_searcher.port");
        $this->index_name = $index_name;
    }

    public static function getSearcher($index = "searcher")
    {
        $index = strtolower($index);
        if (empty(self::$server[$index])) {
            self::$server[$index] = new self($index);
        }
        return self::$server[$index];
    }

    //修改或增加索引
    public function save($type,$id,$data)
    {
        $this->method = "PUT";
        $this->type_name = $type;
        $this->data_id = $id;
        $this->data = $data;
        $res = $this->go();
        return $res;
    }


    //删除索引
    public function del($type,$id)
    {
        $this->method = "delete";
        $this->type_name = $type;
        $this->data_id = $id;
        return $this->go();
    }


    protected function buildRequest()
    {
        return $this->server_ip."/".$this->index_name."/".$this->type_name."/".$this->data_id;
    }

    protected function go()
    {
        $curl = curl_init();
        $this->method = strtoupper($this->method);
        if ($this->method === "POST") {
            curl_setopt($curl,CURLOPT_POST,1);
        } else {
            curl_setopt($curl,CURLOPT_CUSTOMREQUEST,strtoupper($this->method));
        }
        curl_setopt($curl,CURLOPT_POSTFIELDS,json_encode($this->data,JSON_UNESCAPED_UNICODE));
        curl_setopt($curl,CURLOPT_URL,$this->buildRequest());
        curl_setopt($curl,CURLOPT_RETURNTRANSFER,1);
        $res = curl_exec($curl);
        Log::info($res);
        $decode = json_decode($res);
        if (json_last_error()) {
            return false;
        }
        return $decode;
    }

}