<?php

namespace App\Member\v1\Controller;
use App\Http\Response\HttpStatus;
use App\Http\Response\Response;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Illuminate\Routing\Controller;
use App\Member\Model\User as UserModel;
use App\Libraries\Redis\mRedis;


class User extends Controller
{

    const REDIS_AUTHKEY = "userworkspace_auth_ht";

    use \App\Traits\Controller;

    protected $query_fields = [
        "mobile","nickname"
    ];

    public function search()
    {
        $query = request()->query();
        $where = $this->filter($query);
        if (key_exists("mobile",$where)) {
            $model = UserModel::where("mobile",$where["mobile"]);
        } elseif (key_exists("nickname",$where)){
            $model = UserModel::where("nickname",$where["nickname"]);
        } else {
            return Response::success([]);
        }
        $res = $model->select(["id","nickname","mobile","id as uid"])->first();
        return Response::success(!is_null($res)?$res->toArray():[]);
    }

    /**
     *
     */
    public function thirdView($id)
    {
        try {
            $info = UserModel::findOrFail($id , UserModel::u_fields);
            return Response::success($info->toArray());
        } catch (ModelNotFoundException $e) {
            return Response::error("用户未找到");
        }
    }

    /**
     * 用户详情
     */
    public function show($id)
    {
        try {
            $info = UserModel::findOrFail($id , UserModel::fields);
            $info->getRelate(request("relation"));
        } catch (ModelNotFoundException $e) {
            return Response::error("用户未找到");
        }
        return Response::success($info->toArray());
    }

    public function getRelate($id,$relation)
    {
        try {
            $model = SetsModel::findOrFail($id , ["id"]);
            $model->getRelate($relation);
            return Response::success($model->toArray());
        } catch (ModelNotFoundException $e){
            return Response::error(HttpStatus::HttpNotFound,"用户未找到");
        }
    }

    /**
     * 更新一个HASH CODE
     * @return array
     */
    public function code($code = null)
    {
        $redis = mRedis::getRedis();
        if ($code != null) {
            $redis->hDel(self::REDIS_AUTHKEY,$code);
        }
        $time = time();
        $code = hash("sha512",rand(0,10).$time.uniqid());
        $redis->hSet(self::REDIS_AUTHKEY,$code,['expire' => time() + 3600]);
        return Response::success($code);
    }

    /*获取一个用户登录状态*/
    public function getUserByHashCode($code)
    {
        $redis = mRedis::getRedis();
        $user = $redis->hGet(self::REDIS_AUTHKEY,$code);
        if (isset($user['expire']) && $user['expire'] < time()) {
            return Response::error("已过期",HttpStatus::HttpTimeout);
        }
        if (isset($user) && isset($user['id'])) {
            return Response::success(UserModel::getUserInfo($user['id']));
        }else{
            return Response::error("未登录",HttpStatus::HttpUnauthorized);
        }
    }

    /**
     * 根据CODE获取用户信息
     */
    public function getUserIdByHashCode($code = "")
    {
        if (empty($code)) {
            return Response::error("未登录",HttpStatus::HttpUnauthorized);
        }
        $user = UserModel::where("access_token",$code)->first();
        try {
            $user = UserModel::where("access_token",$code)->first();
            return Response::success($user->id);
        } catch (\Exception $e) {
            return Response::error("未登录",HttpStatus::HttpUnauthorized);
        }
    }

}