<?php

namespace App\Photo\v1\Controller;
use App\Http\Response\HttpStatus;
use App\Http\Response\Response;
use App\Traits\Controller;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Symfony\Component\HttpFoundation\Request;
use App\Photo\Model\Photo as PhotoModel;
use App\Photo\Validation\PhotoValidator;


class Photo extends \Illuminate\Routing\Controller
{
    use Controller;
    protected $query_fields = [
        "is_choose", "is_del"
    ];

    /**
     * 首页  列表  全部选片+未选片
     */
    public function index()
    {
        $query = request()->query();
        $where = $this->filter($query);
        is_null($where) && $where = [];
        $row  = isset($query["size"])?$query["size"]:config("app.default_perpage");
        $model = $this->getOrder(PhotoModel::class,$where);
        return Response::success($model->paginate($row)->toArray());
    }


    /**
     * 新建
     * @method
     *  post
     * @param
     *  uid       int                   required
     *  pg_id     int                   required
     *  cover   string                  required
     *  extra_truing_price  float       required
     *  count               int         required
     */
    public function store(Request $request)
    {
        $post = $request->all();
        $validator = new PhotoValidator();
        $res = $validator->validate($post);
        if ($res == false) {
            $messages = $validator->getMessages();
            return Response::error($messages,HttpStatus::HttpValidationFailed);
        }
        $model = PhotoModel::newPhoto($post);
        if ($model !== false) {
            return Response::ok($model->id);
        } else {
            return Response::error();
        }
    }

    public function update($id,Request $request)
    {
        try {
            $model = PhotoModel::findOrFail($id);
            $res = $model->update($request->all());
            if ($res !== false) {
                return Response::ok($model->id);
            } else {
                return Response::error();
            }
        } catch (\Exception $e) {
            return Response::error("选片未找到",HttpStatus::HttpNotFound);
        }
    }

    /**
     * 删除
     */
    public function destory($id)
    {
        try {
            $model = PhotoModel::findOrFail($id);
            $model->delete();
        } catch (ModelNotFoundException $e){}
        return Response::ok();
    }

    public function show($id) {
        try {
            $model = PhotoModel::findOrFail($id);
            return Response::success($model->toArray());
        } catch (ModelNotFoundException $e){
            return Response::error("选片未找到",HttpStatus::HttpNotFound);
        }
    }
}