<?php

namespace App\Providers;

use Illuminate\Support\ServiceProvider;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Log;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        //注册自定义验证

        //汉字字符串长度
        Validator::extend('chinese_length', function($attribute, $value, $parameters, $validator) {
            $strlen = mb_strlen($value,'utf8');
            return ($strlen >= $parameters[0] && $strlen <= $parameters[1]);
        });
        //数组长度
        Validator::extend('array_length_min', function($attribute, $value, $parameters, $validator) {
            if (!is_array($value) && is_string($value)) {
                $value = explode(",",$value);
            }
            $count = count($value);
            return ($count >= $parameters[0]);
        });
        Validator::extend('array_length_max', function($attribute, $value, $parameters, $validator) {
            if (!is_array($value) && is_string($value)) {
                $value = explode(",",$value);
            }
            $count = count($value);
            return ($count <= $parameters[0]);
        });
    }

    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {
        //
    }
}
