<?php

namespace App\Sets\Model;

use App\Sets\Model\Category;
use \Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\Relation;
use Illuminate\Support\Facades\DB;
use App\City\Model\City as CityModel;

class Sets extends Model
{
    use \App\Traits\Models;
    const SHELF_UP  = 0;
    const SHELF_DOWN = 1;
    protected $table = "myp_sets";
    public $timestamps = false;

    protected $fillable = [
        'title', 'cover', 'price', 'photographers_count', 'makeup_count', 'logistics_count', 'join_count', 'duration',
        'negative_count', 'modification_count', 'modification_price', 'modeling_count', 'deadline_of_day',
        'n_cost', 'start_time', 'end_time', 'type', 'abroad', 'uid', 'duration_unit', 'negative_give_all', 'service_city_id',
        'service_city_name', 'is_shelf', 'change_descr', 'other_descr', 'travel_city_id', 'travel_city_name',
        'abroad', 'modeling_count_from_user','is_promotion',"temp_price","type"
    ];

    const fields = [
        'id','title','cover','price','type','is_promotion','is_shelf','create_time'
    ];

    public function __construct(array $attributes = [])
    {
        parent::__construct($attributes);
        $this->beforeValidationOnCreate();
    }

    public function beforeValidationOnCreate()
    {
        $this->collect_count = 0;
        $this->star = 0;
        $this->star_count = 0;
        $this->look_count=0;
        $this->makeup_descr = "";
        $this->scene_descr = "";
        $this->use_score = 0;
        $this->n_order_count = 0;
        $this->n_lock = 0;
        $this->total_sale = 0;
        $this->n_total_sale = 0;
        $this->promotion_id = 0;
        $this->total_sale = 0;
        $this->is_del = 0;
    }

    public function relation_promotion()
    {
        return $this->hasMany(Promotion::class,"sets_id")->where('is_del',0);
    }

    public function relation_attatchment()
    {
        return $this->hasMany(Attachment::class,"sets_id")->where('is_del',0);
    }

    public function relation_works()
    {
        return $this->hasMany(Works::class,"sets_id")->where('is_del',0)->select(['works_id']);
    }

    public function relation_keywords()
    {
        return $this->hasMany(Keywords::class,"sets_id")->where('is_del',0)->select(Keywords::fields);
    }

    public function relation_category()
    {
        return $this->hasMany(Category::class,"sets_id")->where('is_del',0)->select(Category::fields);
    }

    public function relation_comments()
    {
        return $this->hasMany(Comments::class,"sets_id")->where('is_del',0);
    }

    /**
     * 新增
     * return SetsModel | bool
     */
    public static function newSets($data)
    {
        DB::beginTransaction();
        $model = new self;
        try {
            $data['temp_price'] = $data['price'];
            $model->fill($data)->save();
            //促销
            if (isset($data['promotion']) && $data['is_promotion'] == 1) {
                $models = Promotion::add($data['promotion']);
                $model->relation_promotion()->saveMany($models);
            };
            //绑定的样片
            if (isset($data['works'])) {
                $models = Works::add($data['works']);
                $model->relation_works()->saveMany($models);
            };
            //输入的附件
            if (isset($data['attachment'])) {
                $models = Attachment::add($data['attachment']);
                $model->relation_attatchment()->saveMany($models);
            };
            //分类
            if (isset($data['category'])) {
                $models = Category::add($data['category']);
                $model->relation_category()->saveMany($models);
            };
            //关键词
            if (isset($data['keywords'])) {
                $models = Keywords::add($data['keywords'],$data['uid']);
                $model->relation_keywords()->saveMany($models);
            };
        } catch (\Exception $e) {
            self::throwError($e);
            DB::rollback();
            return false;
        }
        DB::commit();
        return $model;
    }

    public function uptSets($data)
    {
        DB::beginTransaction();
        try {
            $data['temp_price'] = $data['price'];
            $this->update($data);
            //促销
            if (isset($data['promotion']) && !empty($data['promotion']) && $data['is_promotion'] == 1) {
                $models = Promotion::add($data['promotion']);
                $this->relation_promotion()->update(['is_del' => 1]);
                $this->relation_promotion()->saveMany($models);
            } elseif ($data['is_promotion'] == 0) {
                $this->relation_promotion()->update(['is_del' => 1]);
                $this->update(['promotion_id' => 0]);
            }
            //绑定的样片
            if (isset($data['works']) && !empty($data['works'])) {
                $models = Works::add($data['works']);
                $this->relation_works()->delete();
                $this->relation_works()->saveMany($models);
            };
            //输入的附件
            if (isset($data['attachment']) && !empty($data['attachment'])) {
                $models = Attachment::add($data['attachment']);
                $this->relation_attatchment()->delete();
                $this->relation_attatchment()->saveMany($models);
            };
            //分类
            if (isset($data['category']) && !empty($data['category'])) {
                $models = Category::add($data['category']);
                $this->relation_category()->delete();
                $this->relation_category()->saveMany($models);
            };
            //关键词
            if (isset($data['keywords']) && !empty($data['keywords'])) {
                $models = Keywords::add($data['keywords'],$this->uid);
                $this->relation_keywords()->delete();
                $this->relation_keywords()->saveMany($models);
            };
        } catch (\Exception $e) {
            self::throwError($e);
            DB::rollback();
            return false;
        }
        DB::commit();
        return true;
    }
}