<?php

namespace App\Sets\Validation;

use App\Http\Validation\ValidatorBase as Validator;
use App\Sets\Validation\AttachmentValidator;
use App\Sets\Validation\PromotionValidator;

class SetsValidator extends Validator
{
    protected $validator = [
        'title'         =>  'required|chinese_length:2,15',
        'cover'         =>  'required',
        'price'         =>  'required|integer|min:5|max:10000',
        'photographers_count'  =>  'required|integer',
        'makeup_count'         => 'required|integer',
        'logistics_count'      => 'required|integer',
        'join_count'           => 'required|integer',
        'duration'       => 'required|integer',
        'negative_count' => 'required|integer',
        'modification_count'   => 'required|integer',
        'modification_price'   => 'required|integer',
        'modeling_count'       => 'required|integer',
        'deadline_of_day'      => 'required|integer',
        'n_cost'               => 'required|min:1',
        'start_time'           => 'required|date',
        'end_time'             => 'required|date',
        'type'                 => 'required|in:0,1',
        'abroad'               => 'required|in:0,1',
        'uid'                  => 'required',
        'duration_unit'        => 'required|in:hour,day,week',
        'negative_give_all'    => 'required',
        'service_city_id'      => 'required',
        'service_city_name'    => 'required',
        'is_shelf'             => 'required|in:0,1',
        'change_descr'         => 'required',
        'other_descr'          => 'required',
        'abroad'               => 'required|in:0,1',
        'modeling_count_from_user' => 'required|min:0',
        'is_promotion'         => "required|in:0,1"
    ];

    protected $message  = [
        'title.required'            =>  '请填写套系名称',
        'title.chinese_length'      =>  '套系名称长度需在2到15字之间',
        'cover.required'            =>  '请选择封面',
        'price.required'            =>  '请填写套系价格',
        'price.integer'             =>  '套系价格为数字',
        'price.min'                 =>  '价格须在5元以上，100,000以下',
        'price.max'                 =>  '价格须在5元以上，100,000以下',
        'photographers_count.required'  =>  '您还未填写人员配备人数',
        'photographers_count.integer'   =>  '配备人数必须是数字',
        'makeup_count.required'         =>  '您还未填写化妆人员人数',
        'makeup_count.integer'          =>  '化妆人员人数必须是数字',
        'logistics_count.required'      =>  '您还未填写后勤人数',
        'logistics_count.integer'       =>  '后勤人数必须是数字',
        'join_count.required'       =>  '您还未填写最多拍摄人数',
        'join_count.integer'        =>  '拍摄人数必须是数字',
        'duration.required'         =>  '您还未填写最多拍摄时长',
        'duration.integer'          =>  '拍摄时长必须是数字',
        'negative_count.required'   =>  '您还未填写底片数量',
        'negative_count.integer'    =>  '底片数量必须是数字',
        'modification_count.required' => '您还未填写精修片数量',
        'modification_count.integer'  => '精修片数量必须是数字',
        'modification_price.required' => '您还未填写额外精修价格',
        'modification_price.integer'  => '额外精修价格必须是数字',
        'modeling_count.required'     => '您还未填写造型数量',
        'modeling_count.integer'      => '造型数量必须是数字',
        'deadline_of_day.required'    => '您还未填写交图天数',
        'deadline_of_day.integer'     => '交图天数必须是数字',
        'n_cost.required'             => '套系可约单数必填',
        'n_cost.min'                  => '套系可约单数必须大于0',
        'start_time.required'         => '请填写开始时间',
        'end_time.required'           => '请填写开始时间',
        'type.required'               => '必须选择为普通套系或旅拍套系',
        'type.in'                     => '套系类型应为0或1',
        'abroad.required'             => '必须填写境内或境外',
        'abroad.in'                   => '境内或境外应为0或1',
        'change_descr.required'       => '改期说明必填',
        'other_descr.required'        => '其它说明必填',
        'service_city_id.required'    => '所属城市ID必填',
        'service_city_name.required'  => '所属城市名称必填',
        'modeling_count_from_user.required' => '允许用户自带必填',
        'negative_give_all.required'  => '摄影师提供数必填',
        'is_shelf.required'           => '上下架状态必填',
        'is_promotion.required'       => '促销状态必填',
        'is_promotion.in'             => '促销状态必须为0或1',
        'is_shelf.in'                 => '上下架必须为0或1',
        'duration_unit.in'            => '时间区间应为小时、天、周',
        'start_time.date'             => '请输入正确的开始时间',
        'end_time.date'               => '请输入正确的结束时间'
    ];

    /**
     * 额外规则
     * @param array $data
     */
    public function custom_validate($data)
    {
        $messages = [];
        if (empty($data['works'])) {
            $messages[] = "该套系至少应绑定一个样片集";
            return $messages;
        }
        if (empty($data['category'])) {
            $messages[] = "该套系必须至少选择一个分类";
            return $messages;
        }
        if ($data['modeling_count'] < $data['modeling_count_from_user']) {
            $messages[] = "摄影师最多提供数不可大于造型总数量";
            return $messages;
        }

        if ($data['start_time'] > $data['end_time']) {
            $messages[] = "套系开始时间必须小于结束时间";
            return $messages;
        }

        if ($data["is_promotion"] == 1 && empty($data['promotion'])) {
            if ($data['promotion'][0]['promotion_start_time'] >= $data['promotion'][0]['promotion_end_time']) {
                $messages[] = "特惠开始时间应小于特惠停止时间";
                return $messages;
            }
            if ((int)$data['promotion'][0]['per_user_count']  > $data['promotion'][0]['p_order_count']) {
                $messages[] = "特惠的限购额度应小于特惠数量";
                return $messages;
            }
            if ($data['promotion'][0]['p_order_count']  <= 0 ) {
                $messages[] = "特惠数量应大于0";
                return $messages;
            }

            if ($data['promotion'][0]['promotion_start_time'] < $data['start_time']) {
                $messages[] = "特惠的开始时间应大于套系的起始有效时间";
                return $messages;
            }

            if ($data['promotion'][0]['promotion_end_time'] > $data['end_time']) {
                $messages[] = "特惠的结束时间应小于在套系终止有效时间";
                return $messages;
            }
            $startdate=strtotime($data['promotion'][0]['promotion_start_time']);
            $enddate=strtotime($data['promotion'][0]['promotion_end_time']);
            $days=round(($enddate-$startdate)/3600/24) ;
            if ($days > 100) {
                $messages[] = "特惠时间长度不应大于100天";
                return $messages;
            }
            if ($data['promotion'][0]['promotion_price'] >= $data['price']) {
                $messages[] = "特惠价格应小于套系价格";
                return $messages;
            }

            if ($data['promotion'][0]['promotion_price'] < 5) {
                $messages[] = "特惠价格应大于5元";
                return $messages;
            }
            $validator = new PromotionValidator();
            $res = $validator->validate($data['promotion']);
            if($res->fails()) {
                $messages[] = $validator->getMessages();
                return $messages;
            }
            unset($validator);
        }
        if (isset($data["attachment"]) && is_array($data["attachment"]) && count($data["attachment"]) > 0) {
            $validator = new AttachmentValidator();
            foreach($data["attachment"] as $item) {
                if(!empty($item['title'])) {
                    $res = $validator->validate($item);
                    if($res == false) {
                        $messages[] = $validator->getMessages();
                        break;
                    }
                }
            }
            unset($validator);
        }
        return $messages;
    }

}