<?php

namespace App\Sets\v1\Controller;

use App\Http\Response\HttpStatus;
use App\Http\Response\Response;
use App\Sets\Model\Sets as SetsModel;
use App\Sets\Validation\SetsValidator;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Symfony\Component\HttpFoundation\Request;
use App\Sets\Events\SetsEditedEvent;
use Illuminate\Support\Facades\Event;

class Sets extends \Illuminate\Routing\Controller
{
    use \App\Traits\Controller;
    /**
     * @var array
     * 查询筛选字段
     */
    protected $query_fields = [
        "is_promotion","title","uid","city","type","abroad","service_city_id","cid","is_shelf"
    ];

    /**
     * 套系列表
     * @method get
     * @param
     * @param  uid   int    option
     * @param  shelf int    option
     * @param
     */
    public function index()
    {
        $query = request()->query();
        $where = $this->filter($query);
        $model = $this->setBlurSearch(SetsModel::class,$where,"title");
        is_null($where) && $where = [];
        $row  = isset($query["size"])?$query["size"]:config("app.default_perpage");
        return Response::success($model->paginate($row)->toArray());
    }

    /**
     * 套系基础数据
     * @param $id
     * @method get
     * @return array
     */
    public function show($id)
    {
        try {
            $info = SetsModel::findOrFail($id);
            $info->getRelate(request("relation"));
            return Response::success($info->toArray());
        } catch (ModelNotFoundException $e){
            return Response::error("套系未找到",HttpStatus::HttpNotFound);
        }
    }

    /**
     * 获取关联信息
     * @param $id
     * @param $relation
     * @return array
     */
    public function getRelate($id,$relation)
    {
        try {
            $model = SetsModel::findOrFail($id , ["id"]);
            $model->getRelate($relation);
            return Response::success($model);
        } catch (ModelNotFoundException $e){
            return Response::error("套系未找到",HttpStatus::HttpNotFound);
        }
    }

    /**
     * method post
     * 新建套系
     */
    public function store(Request $request)
    {
        $validator = new SetsValidator();
        $post = $request->all();
        $res = $validator->validate($post);
        if ($res == false) {
            return Response::error($validator->getMessages(),HttpStatus::HttpValidationFailed);
        }
        $model = SetsModel::newSets($post);
        if ($model !== false) {
            Event::fire(new SetsEditedEvent($model));
            return Response::ok($model->id);
        } else {
            return Response::error(SetsModel::getError());
        }
    }

    /**
     * 修改
     * @param $id
     * @param Request $request
     */
    public function update($id,Request $request)
    {
        try {
            $model = SetsModel::findOrFail($id);
            $data = $request->all();
            $validate_Data = array_merge($model->toArray(),$data);
            $validator = new SetsValidator();
            $res = $validator->validate($validate_Data);
            if ($res == false) {
                $messages = $validator->getMessages();
                return Response::error($messages,HttpStatus::HttpValidationFailed);
            }
            $res = $model->uptSets($data);
            if ($res) {
                Event::fire(new SetsEditedEvent($model));
                return Response::ok($model->id);
            } else {
                return Response::error();
            }
        } catch (ModelNotFoundException $e) {
            return Response::error("样片未找到",HttpStatus::HttpNotFound);
        }
    }

    public function destory($id)
    {
        try {
            $model = SetsModel::findOrFail($id);
            $res = $model->delete();
            if ($res) {
                Event::fire(new SetsEditedEvent($model));
                return Response::ok($model->id);
            } else {
                return Response::error();
            }
        } catch (ModelNotFoundException $e) {
            return Response::error("样片未找到",HttpStatus::HttpNotFound);
        }
    }

    public function all($ids)
    {
        $where['id'] = explode(",",$ids);
        $model = $this->setBlurSearch(SetsModel::class,$where,"id","in");
        return Response::success($model->select(SetsModel::fields)->get());
    }

}