<?php
/**
 * Created by PhpStorm.
 * User: zhuangxin
 * Date: 16-9-9
 * Time: 下午4:15
 */

namespace App\Works\Model;

use App\Photo\v1\Controller\Details;
use App\Works\Events\DetailDeleteEvent;
use App\Works\Model\Details as DetailModel;
use App\Sets\Model\Works as SetsModel;
use App\Traits\Models;
use \Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Event;

class Works extends Model
{
    use Models;
    protected $table = "myp_works";
    public $timestamps = false;

    public function __construct(array $attributes = [])
    {
        parent::__construct($attributes);
        $this->beforeValidationOnCreate();
        $this->skipAttributesOnUpdate();
    }

    public function beforeValidationOnCreate()
    {
        $this->comment_count = 0;
        $this->like_count = 0;
        $this->collect_count = 0;
        $this->look_count = 0;
        $this->from = 0;
        $this->is_hidden = 0;
        $this->ref_count = 0;
        $this->count = 0;
        $this->create_time = date("Y-m-d H:i:s",time());
        $this->is_del = 0;
        $this->introduction = " ";
    }

    public function skipAttributesOnUpdate()
    {
        $this->guard(['create_time','comment_count','like_count','collect_count','look_count']);
    }

    protected $fillable = [
        'uid', 'name', 'cover',"is_hidden","introduction"
    ];

    const fields = [
        'id','name', 'cover',"is_hidden",'create_time'
    ];

    public function relation_sets()
    {
        return $this->hasMany(\App\Sets\Model\Works::class,"works_id")->select("sets_id");
    }

    public function relation_category()
    {
        return $this->hasMany(Category::class,"works_id");
    }

    public function relation_detail()
    {
        return $this->hasMany(Details::class,"works_id");
    }

    public function relation_comments()
    {
        return $this->hasMany(Comments::class,"works_id");
    }

    public function relation_keywords()
    {
        return $this->hasMany(Keywords::class,"works_id");
    }

    public function images(array $resources)
    {
        $details = \App\Works\Model\Details::add($resources);
        return $this->relation_detail()->saveMany($details);
    }

    public static function newWorks(array $data)
    {
        $model = new self;
        DB::beginTransaction();
        try {
            $isSaved = $model->fill($data)->save();
            if (!$isSaved){
                throw new \Exception("保存失败");
            }
            if (isset($data['images']) && !empty($data['images'])) {
                if (!$model->images($data['images'])) {
                    throw new \Exception("保存图片失败");
                }
            }
            if (isset($data['keywords']) && !empty($data['keywords'])) {
                $models = Keywords::add($data['keywords'],$data['uid']);
                $model->relation_keywords()->saveMany($models);
            }
            if (isset($data['sets']) && !empty($data['sets'])) {
                $models = SetsModel::add($data['sets']);
                $model->relation_sets()->saveMany($models);
            }
        } catch (\Exception $e) {
            self::throwError($e);
            DB::rollBack();
            return false;
        }
        DB::commit();
        return $model;
    }

    public function uptWorks(array $data)
    {
        DB::beginTransaction();
        $wait_delete = [];
        try {
            if (isset($data['images']) && !empty($data['images'])) {
                $newImages = array_column($data['images'],"works_url");
                $images = $this->relation_detail()->get();
                if ($images != null) {
                    foreach($images->toArray() as $item) {
                       if(!in_array($item["works_url"],$newImages)) {
                           $wait_delete[] = $item['works_url'];
                       }
                    }
                }
                $details = $this->images($data['images']);
                $this->relation_detail()->delete();
                $this->relation_detail()->saveMany($details);
            }

            if (isset($data['keywords']) && !empty($data['keywords'])) {
                $models = Keywords::add($data['keywords'],$this->uid);
                $this->relation_keywords()->delete();
                $this->relation_keywords()->saveMany($models);
            }

            if (isset($data['sets']) && !empty($data['sets'])) {
                $models = SetsModel::add($data['sets']);
                $this->relation_sets()->delete();
                $this->relation_sets()->saveMany($models);
            }

            $this->update($data);
        } catch (\Exception $e) {
            self::throwError($e);
            DB::rollBack();
            return false;
        }
        DB::commit();
        if (!empty($wait_delete)) {
            Event::fire(new DetailDeleteEvent($wait_delete));
        }
        return true;
    }
}