<?php

namespace App\Works\Validation;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use App\Http\Validation\ValidatorBase as Validator;

class WorksValidator extends Validator
{
    protected $validator = [
        'name'          => 'required|chinese_length:2,15',
        'uid'           => 'required',
        'cover'         => 'required'
    ];

    protected $message  = [
        'name.required'             =>  '请填写样片名称',
        'name.chinese_length'       =>  '样片名称应为2到15字之间',
        'uid.required'              =>  'uid必需',
        'cover.required'            =>  '必须设置封面图片'
    ];

    public function custom_validate($post)
    {
        $message = [];

        if (strtoupper(request()->getMethod()) == "POST" ||
            (strtoupper(request()->getMethod()) == "PUT" && isset($post['details']))
        ) {
            if (!isset($post['details']) || empty($post['details'])) {
                $message[] =  "您必须上传5-15张照片";
                return $message;
            };
            $count = count($post['details']);
            if ($count < 5 || $count > 15) {
                $message[] = "您必须上传5-15张照片";
                return $message;
            }
        }

        if (strtoupper(request()->getMethod()) == "POST" ||
            (strtoupper(request()->getMethod()) == "PUT" && isset($post['sets']))
        ) {
            if (!isset($post['sets']) || empty($post['sets'])) {
                if (!isset($post['FROM_SETS']) || $post['FROM_SETS'] != 1) {
                    $message[] = "您必须绑定至少一个套系";
                    return $message;
                }
            }
        }

        return $message;
    }
}